==> generator-ats-node-webapp-0.8.2.tgz: package/generators/app/phases/prompting.js <==
'use strict';

var _ = require('lodash');
var chalk = require('chalk');
var yosay = require('yosay');
var path = require('path');

function isOAuthSupported(options) {
  return options.server !== 'thin';
}

module.exports = {
  welcome: function welcome() {
    this.log(yosay('Welcome to the incredible ' + chalk.red('ATS NodeJS') + ' generator!'));
  },

  askForModuleName: function askForModuleName() {
    var _this = this;

    var done = this.async();
    var prompts = [{
      name: 'name',
      message: 'Module Name',
      'default': path.basename(process.cwd()),
      filter: _.kebabCase,
      validate: function validate(input) {
        return input.length ? true : false;
      },
      when: !this.pkg.name
    }];
    this.prompt(prompts, function (props) {
      if (props.askAgain) {
        return _this.prompting.askForModuleName.call(_this);
      }
      _this.props = _.extend(_this.props, props);
      done();
    });
  },

  askFor: function askFor() {
    var _this2 = this;

    var done = this.async();
    var prompts = [{
      name: 'description',
      message: 'Description',
      'default': this.pkg.description,
      when: !this.pkg.description
    }, {
      name: 'homepage',
      message: 'Project homepage url',
      'default': this.pkg.homepage,
      when: !this.pkg.homepage
    }, {
      name: 'githubAccount',
      message: 'GitHub username or organization',
      when: !this.pkg.repository
    }, {
      name: 'authorName',
      message: 'Author\'s Name',
      when: !this.pkg.author,
      store: true
    }, {
      name: 'authorEmail',
      message: 'Author\'s Email',
      when: !this.pkg.author,
      store: true
    }, {
      name: 'authorUrl',
      message: 'Author\'s Homepage',
      when: !this.pkg.author,
      store: true
    }, {
      name: 'keywords',
      message: 'Key your keywords (comma to split)',
      when: !this.pkg.keywords,
      filter: _.words
    }, {
      name: 'client',
      message: 'Client Framework',
      type: 'list',
      'default': function _default(val) {
        return val || 'react';
      },
      choices: [{ name: 'React', value: 'react' }, { name: 'Angular', value: 'angular' }],
      when: !this.options.client
    }, {
      name: 'server',
      message: 'Server Type',
      type: 'list',
      'default': function _default(val) {
        return val || 'full';
      },
      choices: [{ name: 'Full Server', value: 'full' }, { name: 'Thin Server (dev only)', value: 'thin' }],
      when: !this.options.server
    }, {
      type: 'checkbox',
      message: 'OAuth Strategies',
      name: 'oauthStrategies',
      choices: [{ name: 'Google', value: 'google', checked: true }, { name: 'Github', value: 'github', checked: true }, { name: 'Facebook', value: 'facebook', checked: true }, { name: 'Twitter', value: 'twitter', checked: true }, { name: 'LinkedIn', value: 'linkedin', checked: true }],
      when: isOAuthSupported(this.options) && !this.options.oauthStrategies
    }];

    this.prompt(prompts, function (props) {
      _this2.props = _.extend(_this2.props, props);

      if (props.githubAccount) {
        _this2.props.repository = props.githubAccount + '/' + _this2.props.name;
      }

      done();
    });
  }
};

==> generator-ats-node-webapp-0.9.0.tgz: package/generators/app/phases/prompting.js <==
'use strict';

var _ = require('lodash');
var chalk = require('chalk');
var yosay = require('yosay');
var path = require('path');

function isOAuthSupported(options) {
  return options.server !== 'thin';
}

module.exports = {
  welcome: function welcome() {
    this.log(yosay('Welcome to the incredible ' + chalk.red('ATS NodeJS') + ' generator!'));
  },

  askForModuleName: function askForModuleName() {
    var _this = this;

    var done = this.async();
    var prompts = [{
      name: 'name',
      message: 'Module Name',
      'default': this.options.name || path.basename(process.cwd()),
      filter: _.kebabCase,
      validate: function validate(input) {
        return input.length ? true : false;
      },
      when: !this.pkg.name && !this.options.name
    }];
    this.prompt(prompts, function (props) {
      if (props.askAgain) {
        return _this.prompting.askForModuleName.call(_this);
      }
      _this.props = _.extend(_this.props, props);
      done();
    });
  },

  askFor: function askFor() {
    var _this2 = this;

    var done = this.async();
    var prompts = [{
      name: 'description',
      message: 'Description',
      'default': this.pkg.description,
      when: !this.pkg.description
    }, {
      name: 'homepage',
      message: 'Project homepage url',
      'default': this.pkg.homepage,
      when: !this.pkg.homepage
    }, {
      name: 'githubAccount',
      message: 'GitHub username or organization',
      when: !this.pkg.repository
    }, {
      name: 'authorName',
      message: 'Author\'s Name',
      when: !this.pkg.author,
      store: true
    }, {
      name: 'authorEmail',
      message: 'Author\'s Email',
      when: !this.pkg.author,
      store: true
    }, {
      name: 'authorUrl',
      message: 'Author\'s Homepage',
      when: !this.pkg.author,
      store: true
    }, {
      name: 'keywords',
      message: 'Key your keywords (comma to split)',
      when: !this.pkg.keywords,
      filter: _.words
    }, {
      name: 'client',
      message: 'Client Framework',
      type: 'list',
      'default': function _default(val) {
        return val || 'react';
      },
      choices: [{ name: 'React', value: 'react' }, { name: 'Angular', value: 'angular' }],
      when: !this.options.client
    }, {
      name: 'server',
      message: 'Server Type',
      type: 'list',
      'default': function _default(val) {
        return val || 'full';
      },
      choices: [{ name: 'Full Server', value: 'full' }, { name: 'Thin Server (dev only)', value: 'thin' }],
      when: !this.options.server
    }, {
      type: 'checkbox',
      message: 'OAuth Strategies',
      name: 'oauthStrategies',
      choices: [{ name: 'Google', value: 'google', checked: true }, { name: 'Github', value: 'github', checked: true }, { name: 'Facebook', value: 'facebook', checked: true }, { name: 'Twitter', value: 'twitter', checked: true }, { name: 'LinkedIn', value: 'linkedin', checked: true }],
      when: isOAuthSupported(this.options) && !this.options.oauthStrategies
    }];

    this.prompt(prompts, function (props) {
      _this2.props = _.extend(_this2.props, props);

      if (props.githubAccount) {
        _this2.props.repository = props.githubAccount + '/' + _this2.props.name;
      }

      done();
    });
  }
};
